@@ -4,13 +4,12 @@
 # 2021 MATLAB implementation by V. Angelidakis <v.angelidakis@qub.ac>
 # 2024 Translated from MATLAB to Python by U.A. Canbolat <utku.canbolat@fau.de>
 
-import sys
-
 from CLUMP import GenerateClump_Ferellec_McDowell
 import sys
+import os
 sys.path.append('../../')
 
-inputGeom = 'ParticleGeometries/Torus.stl'
+inputGeom = os.path.join(os.path.dirname(__file__), 'ParticleGeometries/Torus.stl')
 dmin = 0.1
 rmin = 0.01
 rstep = 0.01
